#ifndef CAMERA_H
#define CAMERA_H

#include "angle.h"
#include "quaternion.h"
#include "vector.h"
#include "matrix4x4.h"
#include "viewport.h"
#include "focal.h"
class NawiGLCanvas;
class wxSize;

class Camera
{
public:
	NawiGLCanvas *parentCanvas;
	double worldRadius;

	Viewport viewport;

	Focal focal;

	// Value used to build the projection matrix
	// Computed from focalLength
	double cotanHalfVerticalAoV;

	Quaternion orientation;
private:
	Vector position;

public:
	double altitude; // Above sea level

	Angle latitude;
	Angle longitude;

	static double minimumDistanceToGround;

	Matrix4x4 projectionMatrix;
	Matrix4x4 viewMatrix;

	Vector referenceCenter;

	Camera( double radius, NawiGLCanvas *parentCanvas );
	const Vector& getPosition() const
	{
		return position;
	}
	void setPosition( const Vector &v );

	void update();
	void reset();
	void setViewport(const wxSize &screen, bool resetting = false);
	void setView();
	void setProjection(Viewport &viewport);
	void updateProjection();
};

#endif // CAMERA_H
