#include "focal.h"
#include "angle.h"
#include <wx/math.h>

const double Focal::diagonal24x36 = sqrt( 24.*24. + 36 *36.);

/*!
 * If only one parameter is given, the focal length will be initialized
 * to the given sensorDiagonal (simulating a "normal" lens).
 */
Focal::Focal(double sensorDiagonal)
	:
	length(sensorDiagonal),
	sensorDiagonal(sensorDiagonal)
{
	wxASSERT( sensorDiagonal != 0. );
}

Focal::Focal(double sensorDiagonal, double length)
	:
	sensorDiagonal(sensorDiagonal),
	length(length)
{
	wxASSERT( sensorDiagonal != 0. );
	wxASSERT( length != 0. );
}

/*!
 * \param sensorDimension Can be either the sensor width, height or diagonal
 * \return Horizontal, vertical or diagonal angle of view
 */
Angle Focal::getAngleOfView(double sensorDimension) const
{
	return Angle( 2 * atan( sensorDimension / (2.*length) ) );
}

double Focal::get24x36EquivalentLength() const
{
	return length / sensorDiagonal * diagonal24x36;
}

/*!
 * \param newSensorDiagonal Will be used to scale the current focal length
 */
void Focal::update(double newSensorDiagonal)
{
	wxASSERT( newSensorDiagonal != 0. );
	length *= newSensorDiagonal / sensorDiagonal;
	sensorDiagonal = newSensorDiagonal;
}
