#include "updatethread.h"
#include "nawiframe.h"
#include "world.h"
#include "nawiglcanvas.h"
#include "exception.h"
#include "downloadmanager.h"
#include <wx/stopwatch.h>

UpdateThread::UpdateThread(NawiFrame *parentWindow)
	:
	wxThread(),
	parentWindow(parentWindow),
	keepUpdating(true)
{
}

UpdateThread::~UpdateThread()
{
}

wxThread::ExitCode UpdateThread::Entry()
{
	const long updateInterval = 200; // Milliseconds
	while( keepUpdating )
	{
		try
		{
			wxStopWatch sw;

			parentWindow->world->update();

			if( parentWindow->world->updatedSinceLastRender )
				wxWakeUpIdle();

			NawiFrame::downloadManager->startNextDownload();

			long elapsedTime = sw.Time();
			long remainingTime = updateInterval - elapsedTime;
			if( remainingTime > 0 )
				wxThread::Sleep(remainingTime);
		}
		catch( Exception &e )
		{
			e.log();
		}
	}
	parentWindow->updateThreadTerminated = true;
}
